/*= defines.h ==================================================================
 *
 * Copyright (c) 2006, Brge Strand
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 *  - Neither the name Brge Strand, his emloyer nor the names of its 
 *    contributors may be used to endorse or promote products derived from this 
 *    software without specific prior written permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * 
 * Project-wide definitions
 * 
 * Version 0.1
 *
 * Tested with avr-gcc (GCC) 3.4.6
 *==============================================================================
 */
 

// Only include this file once
#ifndef DEFINES_H
#define DEFINES_H

#define DEBUG                                       // Enable debugging. Must be enabled in this version!
//#define DEBUG_IF                                  // Enable interactive debug interface


// Global defines
#define LEDON           0x01                        // The LED is to be turned on
#define LEDOFF          0x00                        // The LED is to be turned off
#define WAKE_INT        0x00                        // An external interrupt caused wakeup from sleep
#define WAKE_WAIT       0x01                        // Sleep timer expiratioin caused wakeup from sleep
#define WAKE_PENDING    0x02                        // The wait period has not yet exipred, and wakeup is pending
#define EMPTYCHAR 		0xFF						// Display empty space instead of number


// DSA command parameters passed between functions
#define ISHIGH_D		0x00
#define ISHIGH_S		0x01
#define ISHIGH_A		0x02
#define ISLOW_D			0x03
#define ISLOW_S			0x04
#define ISLOW_A			0x05


// Watchdog timer defines
#define WD_ON			0x00
#define	WD_RESET		0x01
#define WD_OFF			0x02


// CD drive mode variables
#define CD_PENDING		0x00						// MCU is waiting for for transactions to/from CD drive
#define CD_READING_TOC	0x01						// We are waiting for the TOC report from the CD drive
#define CD_PLAYING		0x02						// CD drive is currently playing music
#define CD_STOPPED		0x03						// CD drive is stopped
#define CD_PAUSED		0x04						// CD drive is paused
#define CD_OPENING		0x05						// CD drive is opening
#define CD_OPENED		0x06						// CD drive has finished opening
#define CD_CLOSING		0x07						// CD drive is closing
#define CD_NO_DISC		0x08						// No disc was found


// Use with MCU buttons, not UART as now
// Button definitions
// The MSB of a button definition says whether or not the button is to be repeatedly sent across the air. 
// For example, the Play button is single action whereas the Scan forwards button needs to be held for 
// repeated action. 
#define BTN_NOKEY      0b00000000                   // No button pressed on user interface
#define BTN_REPEAT     0b10000000                   // The mask that marks the repeat-action bit in the button definition
#define BTN_PLAY       0b00000001                   // Single-action Play button pressed on user interface
#define BTN_VOLUP      0b10000010                   // Repeat-action Volume up button pressed
#define BTN_VOLDN      0b10000011                   // Repeat-action Volume down button pressed
#define BTN_STOP       0b00000100                   // Single-action Stop button pressed
#define BTN_SKIPF      0b00000101                   // Single-action Skip forwards button pressed
#define BTN_SKIPB      0b00000110                   // Single-action Skip backwards button pressed
#define BTN_SCANF      0b10000111                   // Repeat-action Scan forwards button pressed
#define BTN_SCANB      0b10001000                   // Repeat-action Scan backwards button pressed


// Error indicators
#define NOERROR             0x00                    // An error indicator that means things went well
#define SOMEERROR           0xFF                    // An error indicator for problems of a generic kind
#define TERMINATE_LOOP_OK   0xFE                    // An error indicator for a loop that finished cleanly
#define TERMINATE_LOOP_FAIL 0xFD                    // An error indicator for a loop that did not finish cleanly
#define TIMEOUT             0xFC                    // An error indicator for timeout


// Local includes
#include "mcu.h"
#include "uartdebug.h"

#endif
