/*= mcu.h ======================================================================
 *
 * Copyright (c) 2006, Brge Strand
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 *  - Neither the name Brge Strand, his emloyer nor the names of its 
 *    contributors may be used to endorse or promote products derived from this 
 *    software without specific prior written permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * 
 * Definitions of functions that the MCU hardware must support. This file should
 * contain no hardware-specific code.
 * 
 * Version 0.1
 *
 * Tested with avr-gcc (GCC) 3.4.6
 *==============================================================================
 */


// Only include this file once
#ifndef MCU_H
#define MCU_H


// Local includes
#include "defines.h"
#include "uartdebug.h"


// General MCU functions
void mcu_init(void);
void mcu_startsamplecounter(void);


// DSA functions, FIX: convert to macros!
char mcu_ishigh_D(void);
char mcu_islow_D(void);
char mcu_ishigh_S(void);
char mcu_islow_S(void);
char mcu_ishigh_A(void);
char mcu_islow_A(void);
void mcu_set_D(void);
void mcu_clear_D(void);
void mcu_set_S(void);
void mcu_clear_S(void);
void mcu_set_A(void);
void mcu_clear_A(void);
void mcu_reset_cd(void);
char mcu_write_DSA(char thedata_H, char thedata_L);
char mcu_read_DSA(void);

// Delay functions
void mcu_wait_ms(unsigned int time);
void mcu_sleep_one_shot_enable(unsigned char time);
void mcu_sleep_one_shot_disable(void);
char mcu_wait_for_event(char event);
void mcu_watchdog(char operation);


// LEDs
void mcu_led(char mode);
void mcu_flip(void);
void mcu_flop(void);


// Buttons
char mcu_getbutton(void);


// DEBUG
#ifdef DEBUG
int mcu_putchar(char c);
char mcu_readkey(void);
int mcu_getchar(void);
void mcu_uart_init(void);
#endif


#endif
