/*= notes.c ====================================================================
 *
 * Copyright (c) 2006, Brge Strand
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *  - Redistributions of source code must retain the above copyright notice, 
 *    this list of conditions and the following disclaimer. 
 *  - Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution. 
 *  - Neither the name Brge Strand, his emloyer nor the names of its 
 *    contributors may be used to endorse or promote products derived from this 
 *    software without specific prior written permission. 
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 * 
 * A summary of the DSA protocol for CD drives.
 * 
 * Version 0.1
 *
 * Tested with avr-gcc (GCC) 3.4.6
 *==============================================================================
 */

// One MCU handles the following:
// - RC5 remote control reception
// - DSA protocol to CD module
// - Polling user interface buttons
// - Updating user display

// The RC5 is fairly timing critical, uses at least one internal MCU timer. Also uses an INT pin to detect phase of incoming signal
// The DSA is double handshake and not clock critical. It uses internal timer to measure timeout. It may also use various pin change interrupts 

// At the heart of the DSA module is a poll-until-timeout-or-desired-pin-change function. 

// Sync at beginning of data transfer:
// D ---____----- TX -> RX
// S ------------ -
// A -----___---- RX -> TX

// Data transfer:
// D ---XXXX---XXXX---XXXX---XXXX---XXXX------ TX -> RX, remember to set D back to 1 before setting S to 1 at end of each bit!
// S ----___----___----___----___----___------ TX -> RX
// A -----___----___----___----___----___----- RX -> TX

// Communications acknowledge:
// D ----XXXXXXXX-- RX -> TX  RX=0 data failure, RX=1 data OK
// S ------______-- RX -> TX
// A ---______----- TX -> RX
